@@ -316,9 +316,9 @@ def spimx4(word,model,words_list1,words_list2):
         # Output the corresponding label from the label data
     return label_data[index]
 
-def rasv(word,model,words_list1,words_list2):
+def rasv(word,model,words_list1,words_list2,thresold=0.6,logic=False,logicmsg="Sorry , I dont know that"):
     def get_similar_word2(input_word, words_list):
-        match = difflib.get_close_matches(input_word, words_list, n=1, cutoff=0.6)
+        match = difflib.get_close_matches(input_word, words_list, n=1, cutoff=thresold)
         if match:
             return match[0]
         else:
@@ -330,14 +330,17 @@ def rasv(word,model,words_list1,words_list2):
             index = words_list1.index(similar_word)
             return words_list2[index]
         else:
-            closest_index = -1
-            closest_distance = float("inf")
-            for i, w in enumerate(words_list1):
-                distance = abs(len(word) - len(w))
-                if distance < closest_distance:
-                    closest_index = i
-                    closest_distance = distance
-            return words_list2[closest_index]
+            if logic == False:
+                closest_index = -1
+                closest_distance = float("inf")
+                for i, w in enumerate(words_list1):
+                    distance = abs(len(word) - len(w))
+                    if distance < closest_distance:
+                        closest_index = i
+                        closest_distance = distance
+                return words_list2[closest_index]
+            else:
+                return logicmsg
             #from googlesearch import search
             #import requests
             #from bs4 import BeautifulSoup
@@ -917,7 +920,16 @@ def nlpm(word,model,words_list1,words_list2,modelname):
     sad = ['miserable', 'sorrowful', 'downcast', 'heartbroken', 'despondent', 'dejected', 'disheartened', 'blue', 'unhappy', 'gloomy', 'melancholy']
     laugh = ['giggle', 'chuckle', 'snicker', 'cackle', 'roar', 'snort', 'chortle', 'laughing', 'guffaw','hearty', 'hilarious']
     cry = ['weep', 'sob', 'whimper', 'sniffle', 'blubber', 'tear', 'wail', 'bawl', 'lament', 'mourn', 'sorrow']
+    vps = ['virtual private server', 'cloud server', 'hosting server', 'remote server']
+    node = ['computing node', 'node', 'server node', 'workstation','server']
     synonyms = {
+        'server':node,
+        'hosting server':vps,
+        'node':node,
+        'virtual private server':vps,
+        'cloud server':vps,
+        'vps':vps,
+        'sorrow':cry,
         'communication':network,
         'blissful':happy2,
         'unhappy':sad,
@@ -1024,7 +1036,7 @@ def nlpm(word,model,words_list1,words_list2,modelname):
         output = rephrase_sentence(x, synonyms)
         return output
     return run(modelname,word,model)
-def model_load(modeltype,input, model,modelname):
+def model_load(modeltype,input, model,modelname="rasv"):
     global words_list1
     global words_list2
     global model_name
@@ -1055,6 +1067,7 @@ def model_load(modeltype,input, model,modelname):
     elif modeltype == "nlpm":
         return nlpm(input,model,words_list1,words_list2,modelname)
     else:
+        print("Modeltype not found , looking in local directory....")
         return modeltype_load(modeltype,input,words_list1,words_list2)
 
 
