@@ -15,4 +15,4 @@ dataset("sample.csv","input","label",model)
 while True:
  prompt = input("You: ")
  #run model and parse input
- print("Bot: ",model_load("rasv",prompt,model,Google=True))
\ No newline at end of file
+ print("Bot: ",model_load("rasv",prompt,model))
\ No newline at end of file
